@@ -187,15 +187,16 @@ sub meth_vdeploy {
 		if ($context->{$con}) { push @selectedObjects, $context->{$con}; }
 	}
 
+	my $errors = {};
 	eval {
 	require connectors::ObjHier;
 	my $refrep = ObjHier->new($dbh, "REPOSITORY", $contextid, $context);
-	$refrep->gethierarchy(\@selectedObjects);
+	$refrep->gethierarchy(\@selectedObjects, $cgi->param("forcedeploy"));
 #	my $ptext = $refrep->dumpall();
 	
 #	print "<TEXTAREA rows=10 cols=100>$ptext</TEXTAREA>";
 
-	my $ret = $refrep->outputupdatable();
+	my $ret = $refrep->outputupdatable($errors);
 	
 	if ($ret > 0) {
 		$ret = $refrep->runsqlgeneratetables();
@@ -218,7 +219,7 @@ sub meth_vdeploy {
 #			my $e =  "<BR>\nlast query is: <I>" . $q->query() . "<BR>\n"; print "$e";
 		}
 		cafDbg->pushstackdump(1);
-		cafDbg->pusherror("10000; ERROR WHILE DEPLOYING : $@ <BR>\nlast query is: <I>$qryText</I>\n");
+		cafDbg->pusherror("10000; ERROR WHILE DEPLOYING $errors->{type} - $errors->{object_id} - $errors->{name} - : $@ <BR>\nlast query is: <I>$qryText</I>\n");
 	}
 
 }
