@@ -378,7 +378,10 @@ package cafetrans;
 "Last Exec Time"           => "Last Exec Time",
 "Last modified"            => "Last modification Date",
 "Last Query"               => "Last Query",
-"Launch Monitor"           => "Launch Monitor",
+"Launch Monitor"           => "Launch the Monitor",
+"Launch"                   => "Launch daemon",
+"Launch once"              => "Execute once",
+"Stop Monitor"             => "Stop the Monitor",
 "length"                   => "length",
 "List"                     => "L",
 "Main Menu"                => "Main Menu",
@@ -686,7 +689,21 @@ package cafetrans;
 "_servere"                 => "Servers edition",
 "_serverl"                 => "List of servers",
 "_install"                 => "CONFIGURATION OF A CAFETERRA CONTEXTE",
-"_sflowm"                  => "Subflows Field mapping",
+
+"_sflowm"                  => "Subflow : Field mapping",
+"_sflowe"                  => "Subflow : scripts and triggers",
+
+"_flowl"                   => "Flow listing",
+"_sflowl"                  => "Sub-flows listing",
+"_flowep"                  => "Flow scripts and triggers",
+"_flowe"                   => "Flow Edition",
+"_flowes"                  => "Sub-Flows",
+"_import"                  => "Import exported Cafeterra objects",
+"_export"                  => "Export Cafeterra objects",
+"_fieldt"                  => "Fields transformation",
+"_lcontainer"              => "Import Containers definition",
+"_lfield"                  => "Import Fields definition",
+
 "sqlscr"                   => "SQL queries",
 "User Id"                  => "User login",
 "_userse"                  => "External users edition",
@@ -721,6 +738,57 @@ package cafetrans;
 "Select For Export"        => "Select",
 "Select For Import"        => "Select",
 "tools"                    => "Tools",
+
+
+
+"alter"                    => "Alter Query",
+"create"                   => "Create Query",
+"ctransform"               => "Field specific transformation",
+"delete"                   => "Delete Query",
+"drop"                     => "Drop Query",
+"fafinish"                 => "After the flow is finished",
+"fastart"                  => "After the flow is started",
+"fbfinish"                 => "Before the flow is finished",
+"fbstart"                  => "Before the flow is started",
+"insert"                   => "Insert Query",
+"onerror"                  => "Errors handler",
+"saconnect"                => "After connect SubFlow",
+"saopen"                   => "After prepare main query",
+"saread"                   => "After read message",
+"satransf"                 => "After start transformation",
+"sawrite"                  => "After write message",
+"sbconnect"                => "Before connect SubFlow",
+"sbopen"                   => "Before prepare main query",
+"sbread"                   => "Before read message",
+"sbtransf"                 => "Before start transformations",
+"sbwrite"                  => "Before write message",
+"select"                   => "Select Query",
+"stransform"               => "Sub flow global transformation",
+"truncate"                 => "Truncate Query",
+"update"                   => "Update Query",
+"user"                     => "Other script",
+"webservice"               => "Web Service Script",
+"Continue"                 => "Continue",
+"Error date"               => "Error Date",
+"FORCE DEPLOY"             => "Force updates",
+"Generate an sql CREATE"   => "Generate an sql CREATE",
+"Generate an sql DELETE"   => "Generate an sql DELETE",
+"Generate an sql DROP"     => "Generate an sql DROP",
+"Generate an sql INSERT"   => "Generate an sql INSERT",
+"Generate an sql SELECT"   => "Generate an sql SELECT",
+"Generate an sql TRUNCATE" => "Generate an sql TRUNCATE",
+"Generate an sql UPDATE"   => "Generate an sql UPDATE",
+"Generate an sql query"    => "Generate an sql query",
+"Installed contexts"       => "Installed contexts",
+"Message types"            => "Message types",
+"Set base directory"       => "Set base directory",
+
+"rename"                   => "Rename Query",
+"sbclose"                  => "Before finishing the query",
+"saclose"                  => "After finishing the query",
+"sbdiscon"                 => "Before disconnect the connector",
+"sadiscon"                 => "After disconnect the connector",
+
 );
 
 
