@@ -47,8 +47,8 @@ package cafetrans;
 "Before write message"     => "Avant ecriture",
 "Blowfish Alogorithm"      => "Algorithme Blowfish",
 "Bottom"                   => "Fin",
-"Buffered?"                => "Indirect ?",
-"bufferedflow"             => "Flux indirect",
+"Buffered?"                => "Historiser ?",
+"bufferedflow"             => "Flux indirect (historis)",
 "Buffered sub flows"       => "Sous-flux indirects",
 "Cafeterra - a product from" => "Cafeterra - un produit de ",
 "Cafeterra the FREE EAI"   => "Cafeterra l'EAI LIBRE",
@@ -379,6 +379,9 @@ package cafetrans;
 "Last modified"            => "Date dernire modification",
 "Last Query"               => "Dernire requete",
 "Launch Monitor"           => "Lancer le Moniteur",
+"Launch"                   => "Lancer demon",
+"Launch once"              => "Executer une fois",
+"Stop Monitor"             => "Arrter le Moniteur",
 "length"                   => "Longueur",
 "List"                     => "L",
 "Main Menu"                => "MENU PRINCIPALE",
@@ -686,7 +689,22 @@ package cafetrans;
 "_servere"                 => "Edition des Serveurs",
 "_serverl"                 => "Liste des serveurs",
 "_install"                 => "CONFIGURATION D'UN CONTEXTE CAFETERRA",
-"_sflowm"                  => "Demi-flux Mapping des champs",
+"_sflowm"                  => "Demi-flux : Mapping des champs",
+"_sflowe"                  => "Demi-flux : scripts et triggers",
+
+
+"_flowl"                   => "Liste des flux",
+"_sflowl"                  => "Liste des sous flux",
+"_flowep"                  => "Flux scripts et triggers",
+"_flowe"                   => "Edition du flux",
+"_flowes"                  => "Demi-Flows",
+"_import"                  => "Importer des objets Cafeterra",
+"_export"                  => "Exporter des objets Cafeterra",
+"_fieldt"                  => "Transformation  de champs",
+"_lcontainer"              => "Importer la definition de Conteneurs",
+"_lfield"                  => "Importer la dfinition de champs de conteneur",
+
+
 "sqlscr"                   => "Requetes SQL",
 "User Id"                  => "Login",
 "_userse"                  => "Edition des utilisateurs externes",
@@ -722,6 +740,58 @@ package cafetrans;
 "Select For Import"        => "Select",
 "tools"                    => "Outils",
 
+
+
+
+"alter"                    => "Requte Alter",
+"create"                   => "Requte Create",
+"ctransform"               => "Transformation d'un champ",
+"delete"                   => "Requte Delete",
+"drop"                     => "Requte drop",
+"fafinish"                 => "Aprs fin flux",
+"fastart"                  => "Aprs dbut flux",
+"fbfinish"                 => "Avant fin du flux",
+"fbstart"                  => "Avant dbut du flux",
+"insert"                   => "Requte Insert",
+"onerror"                  => "Gestion d'erreur",
+"saconnect"                => "Aprs connexion",
+"saopen"                   => "Aps prpare",
+"saread"                   => "Aprs lecture enreg",
+"satransf"                 => "Aprs transformation",
+"sawrite"                  => "Aprs criture",
+"sbconnect"                => "Avant connexion",
+"sbopen"                   => "Avant Prepare",
+"sbread"                   => "Avant Lecture",
+"sbtransf"                 => "Avant transformation",
+"sbwrite"                  => "Avant ecriture",
+"select"                   => "Requte Select",
+"stransform"               => "Transformation globale",
+"truncate"                 => "Requte Truncate",
+"update"                   => "Requte Update",
+"user"                     => "Autres scripits",
+"webservice"               => "Script Web Service",
+"Continue"                 => "Continuer",
+"Error date"               => "Date",
+"FORCE DEPLOY"             => "Forcer la mise  jour",
+"Generate an sql CREATE"   => "Gnrer une requte CREATE",
+"Generate an sql DELETE"   => "Gnrer une requte DELETE",
+"Generate an sql DROP"     => "Gnrer une requte DROP",
+"Generate an sql INSERT"   => "Gnrer une requte INSERT",
+"Generate an sql SELECT"   => "Gnrer une requte SELECT",
+"Generate an sql TRUNCATE" => "Gnrer une requte TRUNCATE",
+"Generate an sql UPDATE"   => "Gnrer une requte UPDATE",
+"Generate an sql query"    => "Gnrer une requte SQL",
+"Installed contexts"       => "Les contextes installs",
+"Message types"            => "Types de message lcontainer.html",
+"Set base directory"       => "Changer le rpertoire de base",
+
+
+"rename"                   => "Requte Query",
+"sbclose"                  => "Avant fermeture de la requte",
+"saclose"                  => "Aprs fermeture de la requte",
+"sbdiscon"                 => "Avant dconnexion du connecteur",
+"sadiscon"                 => "Aprs dconnexion du connecteur",
+
 );
 
  
