@@ -538,11 +538,11 @@ sub meth_editp {
 	}
 	push @$flowscripts, ({step => 'user'}, {step => 'user'});
 
-	$query = $dbh->newquery({ object_id => $object_id , type => 'connector' });
+	$query = $dbh->newquery({ parent_id => $object_id , type => 'connector' });
 	$query->sotherobject();
 	my $otherconnectors = $dbh->hexecfetchall($query) || [];
 	
-	$query = $dbh->newquery({ object_id => $object_id , type => 'container' });
+	$query = $dbh->newquery({ parent_id => $object_id , type => 'container' });
 	$query->sotherobject();
 	my $othercontainers = $dbh->hexecfetchall($query) || [];
 	
@@ -583,14 +583,14 @@ sub meth_veditp {
 
 	#my $scripts = $self->getmyscripts($subflow->{object_id}, $cgi, $dbh);
 	$ret = 1;
-	if ($scripts) {
+#	if ($scripts) {
 		$ret = $dbh->updatemyscripts($object_id, $scripts);
-	}
-	if ($connectors) {
+#	}
+#	if ($connectors) {
 		if ($ret >= 0) {
 			$ret = $dbh->updatemyobjects($object_id, $connectors);
 		}
-	}
+#	}
 	if ($ret > 0) { $dbh->commit(); }
 	else { $dbh->rollback(); }
 
@@ -819,15 +819,6 @@ sub meth_vdocument {
 	$doc{flow}{events} = $refrep->eventslist($object_id);
 	$doc{flow}{vars} = $refrep->varslist($object_id);
 	$doc{flow}{scripts} = $refrep->objectscripts($object_id);
-	if ($doc{flow}{scripts}) {
-		foreach my $s (@{$doc{flow}{scripts}}) {
-			if ($s->{script_id} > 0) {
-				my $o = $refrep->getobject($s->{script_id});
-				$s->{script_name} = $o->{name};
-				$s->{script_label} = $o->{objectlabel};
-			}
-		}
-	}
 
 	my $isf = $refrep->subflows($object_id, "INCOM");
 	my $osf = $refrep->subflows($object_id, "OUTGO");
@@ -863,7 +854,7 @@ sub meth_vdocument {
 		$ob->{events} = $refrep->eventslist($ob->{object_id});
 		$ob->{vars} = $refrep->varslist($ob->{object_id});
 		$ob->{scripts} = $refrep->objectscripts($ob->{object_id});
-		if ($ob->{scripts} > 0) {
+		if ($ob->{scripts}) {
 			foreach my $s (@{$ob->{scripts}}) {
 				if ($s->{script_id} > 0) {
 					my $o = $refrep->getobject($s->{script_id});
@@ -900,20 +891,52 @@ sub meth_vdocument {
 			
 		}
 	}
+
+	my @otherconn;
+	foreach my $oid (@{$refrep->allobjects()}) {
+		my $o = $refrep->getobject($oid);
+		next unless ($o);
+		if ($o->{type} eq 'connetcor') { push @otherconn, $o }
+		if ($o->{type} eq 'container') {
+			if (! ($alltables{$o->{object_id}})) {
+				$o->{_fields} = $refrep->myfields($o->{object_id});
+				$o->{attributes} = $refrep->attributelist($o->{object_id});
+				$o->{vars} = $refrep->varslist($o->{object_id});
+				$alltables{$o->{object_id}} = $o;
+			}
+		}
+	}
 	my @a = values %alltables;
+			
 	$doc{containers} = \@a;
+
+	if ($doc{flow}{scripts}) {
+		foreach my $s (@{$doc{flow}{scripts}}) {
+			next if ($allscripts{$s->{script_id}});
+			if ($s->{script_id} > 0) {
+				my $o = $refrep->getobject($s->{script_id});
+				$s->{script_name} = $o->{name};
+				$s->{script_label} = $o->{objectlabel};
+				$s->{scriptlang} = $o->{type};
+				$allscripts{$s->{script_id}} = $o;
+			}
+		}
+	}
 	{ my @s = values %allscripts; $doc{scripts} = \@s; }
 
 	my %allconnectors;
 	my %allservers;
 	my %allusers;
 	my %allproxies;
-	foreach my $ob (@a) {
-		if ($ob->{parent_id} > 0) {
-			my $c = $refrep->getobject($ob->{parent_id}) if ($ob->{parent_id});
+	push @otherconn, @a;
+	foreach my $ob (@otherconn) {
+		if (($ob->{parent_id} > 0) || ($ob->{type} eq 'connetcor')) {
+			my $c;
+			if ($ob->{type} eq 'connetcor') { $c = $ob; }
+			elsif ($ob->{parent_id}) { $c = $refrep->getobject($ob->{parent_id}); }
 			if ($c) {
-				$ob->{parent_id_name} = $c->{name};
-				if (! $allconnectors{$ob->{parent_id}}) {
+				$ob->{parent_id_name} = $c->{name} unless ($ob->{type} eq 'connetcor');
+				if (! $allconnectors{$c->{object_id}}) {
 					$allconnectors{$c->{parent_id}} = $c;
 					$c->{attributes} = $refrep->attributelist($c->{object_id});
 					$c->{vars} = $refrep->varslist($c->{object_id});
