@@ -45,7 +45,8 @@ sub CanIRun {
 
 	my $query = $qDbh->newquery({ run_id => $runId, object_id => $self->MyId(), syspid => $self->MyPid() });
 	$query->iwrunhisto();
-	my $ret = $qDbh->executefinish($query);
+	my $ret;
+	eval { $ret = $qDbh->executefinish($query); };
 	#return 1;
 
 	$query = $qDbh->newquery({ object_id => $self->MyId(), FORUDPATE => 1 });
@@ -56,6 +57,9 @@ sub CanIRun {
 
 	unless ($status->{rt_status} eq "online") {
 		$self->LogSysTrace("CANIRUN : " . $self->MyId() . " MY STATUS IS / $status->{rt_status}");
+		if ($status->{rt_status} eq "stopped") {
+			if ($self->MyId() == $self->MyFlowId()) {return "stop"; }
+		}
 		return undef unless ($status->{rt_status} eq "online");
 	}
 
@@ -64,10 +68,10 @@ sub CanIRun {
 	$status = $qDbh->hexecfetchrownop($query, "finish");
 
 	$status = { rt_status => "online" } unless ($status);
-	unless ($status->{rt_status} eq "online") {
+	unless(($status->{rt_status} eq "online") || ($status->{rt_status} eq "running")) {
 		$self->LogSysTrace("CANIRUN : " . $self->MyId() . " MONITOR STATUS IS / $status->{rt_status}");
-
-		return undef unless(($status->{rt_status} eq "online") || ($status->{rt_status} eq "running"));
+		if ($status->{rt_status} eq "stopped") { return "stop"; }
+		return undef;
 	}
 
 	my $qAttr = {
@@ -277,6 +281,20 @@ sub StoppedFlow {
 	return (($self->{status}{Stopped}) || ($self->Halted()));
 }
 
+sub TargetCleared {
+	my $self = shift;
+
+	if (@_) { $self->{status}{targetCleared} = shift; }
+	$self->{status}{targetCleared};
+}
+
+sub SkipTruncate {
+	my $self = shift;
+
+	if (@_) { $self->{status}{skipTruncate} = shift; }
+	$self->{status}{skipTruncate};
+}
+
 sub SkipMessage {
 	my $self = shift;
 
@@ -509,7 +527,7 @@ sub RunOutgoingTransformation {
 	my $tablePrefix = $self->GenIncomTableName();
 	my $masterTable = $tablePrefix . "_i";
 	my $dataTable = $tablePrefix . "_id";
-	my $msgCritretia = { mastertable => $masterTable, datatable => $dataTable, msgseq => $oldestIncomMsgId };
+	my $msgCritretia = { mastertable => $masterTable, datatable => $dataTable, ge_msgseq => $oldestIncomMsgId };
 
 	my $query = $qDbh->newquery($msgCritretia);
 	$query->snextincommsg();
@@ -547,8 +565,8 @@ sub RunOutgoingTransformation {
 			$oldestIncomMsgDate = $row->{msgdate};
 		}
 
-		$self->IncomFieldValue($row->{fieldid}, $row->{field_value});
-		$self->OutgoFieldValue($row->{fieldid}, $row->{field_value});
+		$self->IncomFieldValue($row->{field_id}, $row->{field_value});
+		$self->OutgoFieldValue($row->{field_id}, $row->{field_value});
 	}
 
 	foreach my $subFlow (@$flowArr) { $subFlow->AfterTransformation(); } # GAFFE il y a du grabbuge ... tester que before a dj t excut
@@ -577,7 +595,7 @@ sub RunOutgoingSend {
 		my $tablePrefix = $subFlow->GenOutgoTableName();
 		my $masterTable = $tablePrefix . "_o";
 		my $dataTable = $tablePrefix . "_od";
-		my $msgCritretia = { mastertable => $masterTable, datatable => $dataTable, msgseq => $oldestSentMsgId, msgstatus => "transformed" };
+		my $msgCritretia = { mastertable => $masterTable, datatable => $dataTable, ge_msgseq => $oldestSentMsgId, msgstatus => "transformed" };
 		my $query = $qDbh->newquery($msgCritretia);
 		$query->snextoutgomsg();
 		my $ret = $qDbh->execute($query);
@@ -590,7 +608,7 @@ sub RunOutgoingSend {
 					$subFlow->MyCurrSentMsgId($oldestSentMsgId);
 
 					$subFlow->BeforeWrite();
-					if ($subFlow->SkipMessage()) {
+					unless ($subFlow->SkipMessage()) {
 						$subFlow->GetRollBackData();
 						$subFlow->SendMsg();
 					
@@ -600,13 +618,13 @@ sub RunOutgoingSend {
 					$self->CommitIfNeeded();
 				}
 				$subFlow->ClearOutgoFields();
-				last unless ($row);
-				if ($row) {
-					$rowCount++;
-					$oldestSentMsgId = $row->{msgseq};
-				}
 			}
-			$subFlow->OutgoFieldValue($row->{fieldid}, $row->{field_value});
+			last unless ($row);
+			if ($row) {
+				$rowCount++;
+				$oldestSentMsgId = $row->{msgseq};
+			}
+			$subFlow->OutgoFieldValue($row->{field_id}, $row->{field_value});
 		}
 		$qDbh->finish($query);
 
@@ -637,6 +655,7 @@ sub LogIncomMessage {
 	$query->iincommsg();
 	$qDbh->executefinish($query);
 
+#	$self->LogSysTrace("LogIncomMessage msgseq = $msgseq");
 	foreach my $fldname (@$fNames) {
 		my $fldvalue = $self->IncomFieldValue($fldname);
 		if (defined($fldvalue)) {
@@ -685,10 +704,12 @@ sub DirectTransfert {
 					# $subFlow->BeforeOpen();
 					$subFlow->BeforeWrite();
 					$subFlow->GetRollBackData();
-					$subFlow->SendMsg();
+					if (! $subFlow->SkipMessage()) {
+						$subFlow->SendMsg();
 					
-					$subFlow->LogSentMsg();
-					$subFlow->AfterWrite();
+						$subFlow->LogSentMsg();
+						$subFlow->AfterWrite();
+					}
 				}
 				$self->CommitIfNeeded();
 			}
@@ -813,6 +834,7 @@ sub ProcessTerminate {
 	my $self = $SchedRt::classVars;
 
 	eval { $self->LogSysTrace("CAUGHT SIGNAL ", shift, "\n"); };
+	eval { $self->QueueConnect() ; };
 	eval {
 		$self->BeforeStop();
 
@@ -828,7 +850,6 @@ sub ProcessTerminate {
 	if ($@) {
 		die $@ unless ($self->QueueDbhAutocommit() and $self->QueueDbh());
 		eval {
-		print STDERR "ERROR $@\n";
 		$self->LogSysTrace("Fatal Error : $@");
 		local $SIG{__DIE__} = 'IGNORE';
 #		$self->LogSysTrace("ProcessMe OnError");
@@ -908,16 +929,17 @@ sub WebService {
 		$daemon = $self->WebServiceHTTP($attrs);
 	}
 	elsif ($attrs->{WS_PROTOCOL} eq 'WS_PROTO_TCP') {
-		$daemon = $self->WebServiceHTTP($attrs);
+		$daemon = $self->WebServiceTCP($attrs);
 	}
 	else { die "Unkown Protocol $attrs->{WS_PROTOCOL}"; }
 
 	$daemon->dispatch_to('CafeterraWS', 'CafeterraWSI', 'CafeterraWSO');
+	$daemon->AcceptFrom($attrs->{WS_ACCEPT_FROM});
 
 	if ($attrs->{WS_COMPRESSION} > 0) { $daemon->options({compress_threshold => $attrs->{WS_COMPRESSION}}); }
 
 	$self->FinalCommit();
-	$SchedRt::classVars->QueueInactiveDestroy(1);
+#	$SchedRt::classVars->QueueInactiveDestroy(1);
 	$SIG{"TERM"} = \&ProcessTerminate;
 	$SIG{"INT"} = \&ProcessTerminate;
 	$self->QueueDisconnect()  unless ($SchedRt::classVars->QueueInactiveDestroy());
@@ -985,7 +1007,9 @@ sub ProcessFlow {
 		
 		$self->BeforeStart();
 
-		$self->CanIRun () || return;
+		my $canIRun = $self->CanIRun ();
+		if ($canIRun eq "stop") { exit; }
+		return unless ($canIRun);
 		
 		$self->AfterStart();
 
@@ -1113,8 +1137,10 @@ sub WSProcess {
 	$SchedRt::classVars->QueueConnect() unless ($SchedRt::classVars->QueueInactiveDestroy());
 	my $objHier = $SchedRt::classVars->ObjectHierarchy();
 	$objHier->dbh($SchedRt::classVars->QueueDbhAutocommit());
-	if ($class->WSAuthenticate($authinfo)) {
-		$ret = $class->WSLoadService($service, $inparams, $outparams);
+	if ($ret = $class->WSAuthenticate($authinfo)) {
+		if ($service) {
+			$ret = $class->WSLoadService($service, $inparams, $outparams);
+		}
 	}
 	else {
 		$SchedRt::classVars->QueueDisconnect() unless ($SchedRt::classVars->QueueInactiveDestroy());
