@@ -150,6 +150,8 @@ sub QueueDisconnect {
 
 	if (my $qDbh = $self->QueueDbhAutocommit()) { $qDbh->disconnect(); $self->QueueDbhAutocommit(undef); }
 	if (my $qDbh = $self->QueueDbh()) { $qDbh->rollback(); $qDbh->disconnect(); $self->QueueDbh(undef); }
+	$self->QueueDbhAutocommit(undef);
+	$self->QueueDbh(undef);
 }
 
 sub ObjectHierarchy {
@@ -256,6 +258,9 @@ sub InitSystemVars {
 	$SchedRt::classVars->{_System}{commitinterv} = $flow->{commitinterv} || 1;
 	$SchedRt::classVars->{_System}{incomrel} = $flow->{incomrel};
 	$SchedRt::classVars->{_System}{bufferedflow} = $flow->{bufferedflow};
+	$self->LogSysTrace("My type is $flow->{flowtype}");
+	if ($flow->{flowtype} eq 'webservice') { $self->Mode('webservice'); }
+	
  #	$SchedRt::classVars->{_System}{runId} = undef;
  #	$SchedRt::classVars->{_System}{startedTime} = undef;
 	$SchedRt::classVars->{scriptClosures} = {};
@@ -1015,8 +1020,14 @@ sub OnError {
 				$execCtxt = $SchedRt::classVars->{executionContext}[$iCtxt];
 			}
 
-			my $scriptRt = $self->MyClosure ($scrid);
-			$action = $scriptRt->RunScript($execCtxt, $err);
+			eval {
+				my $scriptRt = $self->MyClosure ($scrid);
+				$action = $scriptRt->RunScript($execCtxt, $err);
+			};
+			if ($@) { $action = "HALTE"; $err .= "<BR>\n$@"; }
+			if (($action eq "CASCADE") and ($self->MyId() != $self->MyFlowId())) {
+				$SchedRt::classVars->OnError($err); return;
+			}
 
 #			if ($ret eq "HALTE") { $self->HalteOnError($err); }
 #			elsif ($ret eq "SKIP") { $self->SkipRowOnError($err); }
@@ -1027,7 +1038,7 @@ sub OnError {
 	}
 	if ($action eq "HALTE") { $self->HalteOnError($err); }
 	elsif ($action eq "SKIP") { $self->SkipRowOnError($err); }
-	elsif ($action eq "RETRYLATER") { $self->RetryLaterOnError($err); }
+	elsif ($action eq "TRYLATER") { $self->RetryLaterOnError($err); }
 	elsif ($action eq "STOP") { $self->StopOnError($err); }
 	else { $self->HalteOnError(); }
 
@@ -1136,8 +1147,8 @@ sub GetQueryById {
 		elsif ($chunk->{type} eq 'IV') { $qtext .= $self->ParseVarName($chunk->{content}); }
 		elsif ($chunk->{type} eq 'BV') { $qtext .= "?"; }
 	}
-	my @bindvars = @{$parsed->{bindvars}};
-	my @columns  = @{$parsed->{aliases}};
+	my @bindvars = @{$parsed->{bindvars}||[]};
+	my @columns  = @{$parsed->{aliases} || []};
 
 	$qtext =~ s/\r//g;
 	my $query = { mylabel => "q$qryId", query => $qtext, bindvarlabels => \@bindvars, columns => \@columns };
@@ -1505,6 +1516,40 @@ sub ExecuteFetchQuery {
 	my ($qh, $dbh) = $params->{query_text} ? $self->PrepareQueryText ($params) : $self->PrepareQuery ($params);
 	return undef unless ($qh and $dbh);
 
+	my $rows;
+	my $ret;
+	if ($first) { $rows = $dbh->execfetchrownop($qh, 1); $ret = $rows; $rows = $rows ? [ $rows ] : $rows; }
+	else { $rows = $dbh->execfetchall($qh); $ret = $rows; }
+
+	return undef unless ($ret);
+
+	if ($format =~ /hash/i) {
+		$ret = [];
+		my $columnsAliases = $qh->columns();
+		foreach my $r (@$rows) {
+			my $rt;
+			for (my $i = 0; $i <= $#$columnsAliases; $i++) {
+				my $varname = $columnsAliases->[$i];
+				$varname =~ s/^([cfitsgo])_//; # Column, Flow, Incomming, Outgoing, SubFlow, Temporary, Global, 
+				$rt->{$varname} = $r->[$i];
+			}
+			push @$ret, $rt;
+		}
+		$rows = $ret;
+	}
+	elsif ($format =~ /parse/i) {
+		my $r = $rows->[0];
+		my $columnsAliases = $qh->columns();
+		for (my $i = 0; $i <= $#$columnsAliases; $i++) {
+			$self->ParseVarName($columnsAliases->[$i], $r->[$i]);
+		}
+	}
+	elsif ($format !~ /array/i) { return undef; }
+	return $ret unless ($first);
+	return $ret->[0];
+		
+		
+=over
 	if ($format =~ /array/i) { 
 		return $dbh->execfetchrownop($qh, 1) if ($first);
 		return $dbh->execfetchall($qh);
@@ -1515,6 +1560,7 @@ sub ExecuteFetchQuery {
 	}
 
 	else { return undef; }
+=cut
 }
 
 # DBH INTERFACE FOR SCRIPT #
@@ -1726,6 +1772,12 @@ sub DestroyScript {
 	$self->{closure} = undef;
 }
 
+sub skiptruncate {
+	my $self = shift;
+	my $flowCallBack = $self->CallBackObject();
+	$flowCallBack->SkipTruncate(@_);
+}
+
 sub skip {
 	my $self = shift;
 	my $flowCallBack = $self->CallBackObject();
