@@ -22,8 +22,9 @@
 #
 use 5.005;
 use strict;
-use  File::stat;
-use  Fcntl ':mode';
+use File::stat;
+use File::Spec;
+use Fcntl ':mode';
 use Cwd;
 package cafInstall;
 
@@ -111,11 +112,85 @@ OneNeeded => [
 	],
 };
 
+sub GetTheConfig {
+	my $self = shift;
+	my $basedir = shift;
+	my $context = shift;
+
+	my $dir = File::Spec->catdir($basedir, $context) if ($context);
+	my $conffile = File::Spec->catfile($dir, "conf.pm");
+
+	my $ret = undef;
+
+	if ((-d $dir) and (-f $conffile)) {
+		if (open (F, $conffile)) {
+			my $isconf;
+			my $version = undef;
+			while (my $l = <F>) {
+				if ($isconf) {
+					if ($l =~ /my\s*\$version\s*=\s*"([^"]*)"/) { $version = $1; }
+					elsif ($l =~ /my\s*\$contextlabel\s*=\s*"([^"]*)"/) {
+						$ret = { contextid => $context,  contextlabel => "$context -- $1", version => $version };
+						last;
+					}
+				}
+				elsif ($l =~ /^\s*package\s*conf|^\s*package\s*CTXTCFG/) { $isconf = 1; }
+			}
+			close F;
+		}
+	}
+	$ret;
+}
+
+sub GetConfigList {
+	my $self = shift;
+	my $basedir = shift;
+
+	my @ConfigList;
+	if (opendir(D, $basedir)) {
+		my @files = readdir(D);
+		close D;
+		foreach my $f (@files) {
+			next if ((! $f) or ($f =~ /^\./) or (! -d $f));
+			my $result = $self->GetTheConfig($basedir, $f);
+			if ($result) {
+				$result->{version} = "<020004" unless($result->{version});
+				$result->{contextlabel} .= " ($result->{version})";
+				push @ConfigList, $result;
+			}
+=cut
+			my $dir = File::Spec->catdir($basedir, $f);
+#								print "GetConfigList $basedir == $dir<BR>";
+			my $conffile = File::Spec->catfile($dir, "conf.pm");
+			if ((-d $dir) and (-f $conffile)) {
+				if (open (F, $conffile)) {
+					my $isconf;
+					my $version = "<020004";
+					while (my $l = <F>) {
+						if ($isconf) {
+							if ($l =~ /my\s*\$version\s*=\s*"([^"]*)"/) { $version = $1; }
+							if ($l =~ /my\s*\$contextlabel\s*=\s*"([^"]*)"/) {
+								push @ConfigList, { contextid => $f,  contextlabel => "$f -- $1 ($version)" };
+								last;
+							}
+						}
+						elsif ($l =~ /^\s*package\s*conf|^\s*package\s*CTXTCFG/) { $isconf = 1; }
+					}
+					close F;
+				}
+			}
+=cut
+		}
+	}
+
+	return ($#ConfigList > -1) ? \@ConfigList : undef;
+}
+
 sub GetConfig {
 	my $self = shift;
 	my $context = shift || "cgi";
-	$context = "cgi" if ($context =~ /desing/i);
-	my $required = $context . "conf";
+	$context = "cgi" if ($context =~ /design/i);
+	my $required = $context . "::conf";
 
 	eval "require $required";
 
@@ -123,18 +198,38 @@ sub GetConfig {
 	return { basedir => $cwd } if ($@);
 	
 	my $conf;
-	if ($context eq 'cgi') { $conf = conf->new(); }
-	else { $conf = CTXTCFG->new(); }
+	my $ctxttype;
+	if ($context eq 'cgi') { $conf = conf->new(); $ctxttype = "design"; }
+	else { $conf = CTXTCFG->new(); $ctxttype = "prod"; }
 
 	my $db = $conf->refdb();
 	my $dsn = $db->{connector}{dbidsn};
+	my $dbname = (split(":", $dsn))[2];
+	$dbname =~ s/;.*//;
+	$dbname =~ s/.*=//;
 	my $user = $db->{user}{username};
 	my $pass = $db->{user}{password};
 	my $basedir = $conf->wd();
 
-	return { dsn => $dsn, user => $user, pass => $pass, basedir => $basedir }
+	return { _contextid => $context, _ctxttype => $ctxttype,
+				_contextdsn => $dsn, _contextuser => $user, _contextpwd => $pass, _basedir => $basedir,
+				_contextdbname => $dbname, _docalias => $conf->{cafsite}, _cgialias => $conf->{cgialias},
+				_httpdpath => $conf->{httpdpath}, _contextlabel => $conf->{contextlabel}  };
 }
 
+sub _getcheckfields2 {
+	my $self = shift;
+	my $cgi = shift;
+	my $checkfields= shift;
+
+	my $OLDVALUES = $self->GetConfig($cgi->param("_contextid"));
+	$self->{_checkfields} = $checkfields;
+	foreach my $fld (@{$checkfields}) {
+		#$self->_datavar($fld->{fName}, $cgi->param($fld->{fName}) || $OLDVALUES->{$fld->{fName}});
+		$self->_datavar($fld->{fName}, $OLDVALUES->{$fld->{fName}});
+	}
+}
+	
 sub TestPerlModules {
 	my $self = shift;
 	my @results;
@@ -142,6 +237,7 @@ sub TestPerlModules {
 		my $mods = $perlModules->{$key};
 		foreach my $mod (@$mods) {
 			my $notfound = 1;
+			my $err;
 			if ($key eq "OneNeeded") {
 				my @mods2 = split (/\s+/, $mod->[0]);
 				foreach my $mod2 (@mods2) {
@@ -156,8 +252,9 @@ sub TestPerlModules {
 				my $evalstr = "require $mod->[0];";
 				eval $evalstr;
 				$notfound = 0 unless ($@);
+				$err = $@;
 			}
-			if ($notfound) { push @results, { _code => $mod->[0], _text => $mod->[1] }; }
+			if ($notfound) { push @results, { _code => $mod->[0], _text => $mod->[1] . " " . $err }; }
 		}
 	}
 	$self->_datavar("_result", \@results);
@@ -308,6 +405,7 @@ sub CreateDb {
 		my $query = $dbh->newquery();
 		$query->query($queryText);
 		eval { $dbh->executefinish($query); };
+		$self->_datavar("_dbnewlycreated", 1);
 		if ($@) { cafDbg->pusherror("CREATE DB $cdbname; $@<BR><I>$queryText</I>"); return 1; }
 	}
 	if ($createdbuser) {
@@ -416,6 +514,42 @@ sub InitialObjects {
 	push @$installInfo, $errText;
 }
 
+sub UpdateObjects {
+	my $self = shift;
+	my $dropObjects = $self->_datavar("_dropobjects") || $self->_datavar("_dbnewlycreated");
+
+	return 1 if ($dropObjects);
+
+	my $basedir = $self->_datavar("_basedir");
+	my $design = $self->_datavar("_ctxttype") eq "design" ? 1 : 0;
+	my $dir = $design ? "" : $self->_datavar("_contextid");
+	$dir =~ s/[^[:alnum:]_]//g;
+	if ($dir and ($dir !~ /^[[:alpha:]]/)) { $dir = "_$dir"; }
+	$dir = "cgi" unless ($dir);
+	my $installed = $self->GetTheConfig($basedir, $dir);
+	$installed->{version} = $installed->{version} || "020000";
+	$installed->{dir} = $basedir;
+
+	my ($dsn, $user, $pwd) = ($self->_datavar("_contextdsn"), $self->_datavar("_contextuser"), $self->_datavar("_contextpwd"));
+	my $dbh = $self->_systemvar("_CONTEXTDBH_");
+	unless ($dbh) {
+		eval { $dbh = $self->IsDbExists($dsn, $user, $pwd); };
+	}
+	if ($dbh) {
+		$installed->{dbh} = $dbh->dbh();
+		require install::Pg::InitSqlScript;
+		my $initObjAndData = InitObjAndData->new();
+		$installed->{indexes} = $initObjAndData->Indexes();
+		$installed->{dropindexes} = $initObjAndData->DropIndexes();
+		require install::Pg::AlterDbObjects;
+		my $alterDbObjects = AlterDbObjects->new($dbh->{dbh}, $installed);
+		$alterDbObjects->go();
+		$alterDbObjects = $alterDbObjects->destroyme();
+		$installed = undef;
+	}
+	return;
+}
+
 sub CreateDirAndConfig {
 	my $self = shift;
 
@@ -533,8 +667,6 @@ sub CreateDirAndConfig {
 		push @$installInfo, $errText;
 	}
 
-
-
 }
 
 sub TestDba {
@@ -574,7 +706,7 @@ sub startpage {
 	my $conf =  $self->{_system}{_conf};
 	my $curraction = $self->_hiddenvar ("_curraction");
 #	if (($curraction ne "create") and ($curraction ne "search") and ($curraction ne "checkpm")) {$curraction = 'search' }
-	if ('search;checkpm;create;checkfp' !~ $curraction) {$curraction = 'search'; }
+	if ('search2;search;checkpm;create;checkfp' !~ $curraction) {$curraction = 'search'; }
 	unless($curraction) { $curraction = 'search'; }
 	$self->_hiddenvar ("_curraction", $curraction);
 	my $meth_name = "meth_$curraction";
@@ -587,6 +719,19 @@ sub startpage {
 	$self->$meth_name($cgi, $dbh, $conf);
 }
 
+sub meth_search2 {
+	my $self = shift;
+	my $cgi = shift;
+	my $dbh = shift;
+	my $conf = shift;
+
+	my $pwd = Cwd->getcwd();
+	$self->_getcheckfields2 ($cgi, $editfields);
+	$self->_datavar("_basedir", $pwd) unless ($self->_datavar("_basedir"));
+	$self->_datavar("_httpdpath", $self->TestHttpdConf($self->_datavar("_httpdpath")));
+	$self->_datavar("_configlist", $self->GetConfigList($self->_datavar("_basedir")));
+}
+
 sub meth_search {
 	my $self = shift;
 	my $cgi = shift;
@@ -597,6 +742,7 @@ sub meth_search {
 	$self->_getcheckfields ($cgi, $editfields);
 	$self->_datavar("_basedir", $pwd) unless ($self->_datavar("_basedir"));
 	$self->_datavar("_httpdpath", $self->TestHttpdConf($self->_datavar("_httpdpath")));
+	$self->_datavar("_configlist", $self->GetConfigList($self->_datavar("_basedir")));
 }
 
 sub PrimaryChecks {
@@ -736,6 +882,7 @@ sub meth_checkpm {
 #	}
 	
 	$self->TestPerlModules();
+	$self->_datavar("_configlist", $self->GetConfigList($self->_datavar("_basedir")));
 }
 
 sub meth_checkfp {
@@ -756,6 +903,7 @@ sub meth_checkfp {
 #	}
 	
 	$self->FileAccess($<, $self->_datavar("_basedir"));
+	$self->_datavar("_configlist", $self->GetConfigList($self->_datavar("_basedir")));
 
 }
 
@@ -769,8 +917,8 @@ sub meth_create {
 	$self->_getcheckfields ($cgi, $editfields);
 
 	my $ret = $self->PrimaryChecks($cgi, $dbh, $conf);
+	my $dbh;
 	if ($ret) {
-		my $dbh;
 		if ($dbh = $self->_systemvar("_CONTEXTDBH_")) { $dbh->disconnect(); }
 		if ($dbh = $self->_systemvar("_MASTERDBH_")) { $dbh->disconnect(); }
 		return undef;
@@ -778,8 +926,11 @@ sub meth_create {
 
 	$self->CreateDb();
 	$self->InitialObjects();
+	$self->UpdateObjects();
 	$self->CreateDirAndConfig();
-	
+	$self->_datavar("_configlist", $self->GetConfigList($self->_datavar("_basedir")));
+	if ($dbh = $self->_systemvar("_CONTEXTDBH_")) { $dbh->disconnect(); }
+	if ($dbh = $self->_systemvar("_MASTERDBH_")) { $dbh->disconnect(); }
 
 }
 
