@@ -424,6 +424,7 @@ sub getflowhierarchy {
 sub gethierarchy {
 	my $self = shift;
 	my $objid = shift;
+	my $force = shift;
 
 	my $dbh = $self->dbh();
 
@@ -451,14 +452,14 @@ sub gethierarchy {
 
 	if ($self->running() eq "QUEUE") {
 		if ($self->lastupdate()) {
-			$query = $dbh->newquery({object_id => \@objids, since => $self->lastupdate(), contextid => $self->contextid(),});
+			$query = $dbh->newquery({object_id => \@objids, since => $self->lastupdate(), contextid => $self->contextid(), FORCE => $force,});
 			$query->sobjectstoupdate();
 			$self->objectstoupdate($dbh->hexecfetchall($query));
 		}
 		$self->lastupdate($dbh->now());
 	}
 	elsif ($self->running() eq "REPOSITORY") {
-		$query = $dbh->newquery({object_id => \@objids, contextid => $self->contextid() });
+		$query = $dbh->newquery({object_id => \@objids, contextid => $self->contextid(), FORCE => $force, });
 		$query->sdeployedtoupdate();
 #		print $query->query(), "<P>";
 		$self->objectstoupdate($dbh->hexecfetchall($query));
@@ -1327,6 +1328,7 @@ sub runsqlgeneratetables {
 
 sub outputupdatable {
 	my $self = shift;
+	my $errors = shift || {};
 
 	my $context = $self->context();
 	my $connector = $self->getdata($context->{connector_id});
@@ -1359,6 +1361,10 @@ sub outputupdatable {
 		foreach my $object (@$updatable) {
 
 			next unless ($object->{object_id} > 0);
+			my $o = $self->getobject($object->{object_id});
+			$errors->{ object_id } = $o->{object_id};
+			$errors->{ name } = $o->{name};
+			$errors->{ type } = $o->{type};
 			my $type = $object->{type};
 			$type = "scripts" if ($type eq "sql" or $type eq "perl");
 
