@@ -10,7 +10,7 @@
 CREATE TABLE cafproxy (
 	object_id integer NOT NULL,
 	user_id integer NOT NULL,
-	port integer NOT NULL,
+	port varchar(20) NOT NULL,
 	dbidsn character varying(250),
 	cipher character varying,
 	key character varying,
