@@ -24,6 +24,8 @@ INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype",
 INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('ROWSCOUNT','all','XCEL','container','atome','Rows Count','','no');
 INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('FILENAME','all','XCEL','connector','atome','File Name','','no');
 INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('TITLESROW','all','XCEL','container','atome','Titles Row','','no');
+INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_ACCEPT_FROM','all','all','webservice','string','Webservice Allowed Hosts','--nodefault--','no');
+INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_INTERFACE','all','all','webservice','string','Webservice Listen Interface','--nodefault--','no');
 INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_PORT','all','all','webservice','number','Webservice Port','--nodefault--','no');
 INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_TYPE','all','all','webservice','list','Webservice Type','WS_SOAP;WS_SOAP;WS_XMLRPC','no');
 INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_COMPRESSION','all','all','webservice','number','Webservice Compression threshold','--nodefault--','no');
