@@ -159,5 +159,12 @@ INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR'
 INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','XCEL','CHAR');
 INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','DIRSL','VARCHAR');
 INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','DIRSL','NUMBER');
+INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','HPRIM','CHAR');
+INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','HPRIM','VARCHAR');
+INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','HPRIM','DATETIME');
+INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','HPRIM','BLOB');
+INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','HPRIM','INTEGER');
+INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','HPRIM','TEXT');
+INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','HPRIM','REAL');
 -- Enable triggers
 
