@@ -81,3 +81,5 @@ INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUE
 INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('Generic','DBI','Generic DBI Driver','yes');
 INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('DIRSL','FTP','Directory listing','');
 INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('DIRSL','LFS','Directory listing','');
+INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HPRIM','FTP','HPRIM Driver','');
+INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HPRIM','LFS','HPRIM Driver','');
