@@ -61,7 +61,8 @@ sub StartSubFlow {
 	$self->MailOnSuccess($subFlow->{mailonsucc});
 	$self->OnErrorAction($subFlow->{onoutgoerr});
 	$self->MyFlowMethod($subFlow->{flowmethod});
-	return (undef) unless($self->CanIRun());
+	my $canIRun = $self->CanIRun();
+	return (undef) unless($canIRun == 1);
 
 #	$self->OpenExternalDb();
 	$self;
@@ -70,7 +71,7 @@ sub StartSubFlow {
 sub MyFlowMethod {
 	my $self = shift;
 
-	if (@_) { $self->{MyFlowMethod} = shift; }
+	if (@_) { $self->{myFlowMethod} = shift; }
 	$self->{myFlowMethod};
 }
 
@@ -121,7 +122,7 @@ sub CloseSubFlow {
 	my $self = shift;
 	my $force = shift;
 
-	$self->BeforeClose();
+#	$self->BeforeClose();
 
 	$self->LogSysTrace("CloseSubFlow ". $self->MyId() . " KeepAlive = " . $self->KeepAlive());
 	if ($force || (! $self->KeepAlive())) {
@@ -407,7 +408,7 @@ sub FinishGetNextMessage {
 	my $dbh = shift;
 
 	$self->AfterTransformation();
-	$self->BeforeClose();
+#	$self->BeforeClose();
 	$self->LogSysTrace("GetNextMessage Finishing Query $dbh For " . $self->MyId());
 	$dbh->finish($query);
 	$self->ClearIncomFields();
@@ -638,13 +639,12 @@ sub ExecuteSendQuery {
 	my $type = shift || "usedfor";
 
 	my $queryText;
-#	print STDERR "ExecuteSendQuery $dbh $which / $type\n";
-#	$self->LogSysTrace("ExecuteSendQuery $which $type : STARTED - PREPARING");
 	if ($type eq "usedfor") { $queryText = $self->GetQueryByUsedFor ($which); }
 	elsif ($type eq "step") { $queryText = $self->GetQueryByStep ($which); }
 	elsif ($type eq "name") { $queryText = $self->GetQueryByName ($which); }
 	elsif ($type eq "id") { $queryText = $self->GetQueryById ($which); }
 
+#	$self->LogSysTrace("ExecuteSendQuery $which $type : STARTED - PREPARING $queryText");
 	return 0 unless ($queryText);
 	my $query = $dbh->newqueryfromhash($queryText);
 
@@ -662,10 +662,10 @@ sub ExecuteSendQuery {
 	#print "calling executefinish\n";
 	#<STDIN>;
 #	print "ExecuteSendQuery $dbh\n";
-#	$self->LogSysTrace("ExecuteSendQuery $which $type : STARTED - EXECUTING with : " . join (" -", @bindVars));
 #	$dbh->trace();
 	my $ret = $dbh->executefinish($query);
-	$dbh->untrace();
+#	$self->LogSysTrace("ExecuteSendQuery [$ret] $which $type : STARTED - EXECUTING with : " . join (" -", @bindVars));
+#	$dbh->untrace();
 #	$self->LogSysTrace("ExecuteSendQuery $which $type : ENDED");
 	$ret;
 }
@@ -675,10 +675,12 @@ sub SendMsg {
 
 	$self->PushContext("sendmsg");
 	my $dbh = $self->GetExternalDbh();
-#	$self->LogSysTrace(print "SendMsg $dbh");
+#	$self->LogSysTrace("SendMsg $dbh");
 
 	my $action;
 	my $type;
+	my $method = $self->MyFlowMethod();
+		
 	if ($action = $self->UserDefinedAction("step")) { $type = "step"; }
 	elsif ($action = $self->UserDefinedAction("name")) { $type = "name"; }
 	elsif ($action = $self->UserDefinedAction("id")) { $type = "id"; }
@@ -686,16 +688,17 @@ sub SendMsg {
 
 	my $ret = 0;
 	$self->BeforeOpen();
+	if ($method eq 'truncate') { $self->ClearTarget() unless($self->SkipTruncate()); }
 	eval {
 		# $ret = $self->ExecuteSendQuery($dbh,"sendmsg");
 		$ret = $self->ExecuteSendQuery($dbh,$action, $type);
 	};
-	$self->AfterOpen();
 	my $e = $@ || "";
+	my $e1 = " (sendmsg returned $ret) ";
+	$self->AfterOpen();
 #	print "SENDMSG ==> $ret";
 	if ($ret == 0) {
-		my $method = $self->MyFlowMethod();
-		if ($method = /updins|delins|insupd/) {
+		if ($method =~ /updins|delins|insupd/) {
 			if ($action = $self->UserAlternateAction("step")) { $type = "step"; }
 			elsif ($action = $self->UserAlternateAction("name")) { $type = "name"; }
 			elsif ($action = $self->UserAlternateAction("id")) { $type = "id"; }
@@ -706,7 +709,7 @@ sub SendMsg {
 				$ret = $self->ExecuteSendQuery($dbh,$action, $type);
 			};
 		}
-		if ($@) { $e .= " THEN " . $@; }
+		if ($@) { $e .= " $e1 THEN " . $@; }
 		else { $e = undef; }
 #		print " SENDMSGBIS ==> $ret";
 	}
@@ -733,6 +736,7 @@ sub FinalCommit {
 
 	$self->LogSysTrace("Final Commit for ". $self->MyId());
 	$self->PushContext("FinalCommit");
+	$self->BeforeClose();
 	my $dbh = $self->GetExternalDbh();
 
 	$dbh->finalcommit() if ($dbh);
@@ -807,8 +811,7 @@ sub ClearTarget {
 	my $dbh = $self->GetExternalDbh();
 	$self->PushContext("cleartarget");
 	eval {
-	if ($self->{flowmethod} eq 'truncate') {
-		unless ($qryh = $self->{QURIESH}{cleartarget}) {
+		unless ($qryh = $self->{QUERIESH}{cleartarget}) {
 			my $q;
 			if ($q = $self->GetQueryByUsedFor('cleartarget')) {
 				$qryh = $dbh->newqueryfromhash($q);
@@ -816,9 +819,8 @@ sub ClearTarget {
 			}
 		}
 		unless ($qryh->_attribute("sth")) {
-			$dbh->execute($qryh);
+			$dbh->executefinish($qryh);
 		}
-	}
 	};
 	if ($@) { $self->OnError($@); }
 	$self->PopContext("cleartarget");
