@@ -187,8 +187,10 @@ sub run {
 			$self->UpdateMyStatus({ next_exectime => cafUtils->datetime1($time) });
 			while ($time > $now) {
 				local $SIG{USR1} = sub { $classVars->Terminate(); };
+				local $SIG{USR2} = sub { $classVars->TerminateUSR2(); };
 				sleep($time-$now);
 				$SIG{USR1} = 'IGNORE';
+				$SIG{USR2} = 'IGNORE';
 				$now = time;
 			}
 			$self->execute($index);
@@ -251,6 +253,7 @@ sub run {
 			my $plabel = $self->MyId();
 			$plabel = "MONITOR" unless ($plabel > 0);
 			$0 = "CAFETERRA $class $plabel ";
+			$self->UpdateMyStatus ();
 
 			if ($self->Mode() eq "once") { $self->ProcessFlow(); }
 			elsif ($self->Mode() eq "webservice") { $self->ProcessFlow(); }
@@ -274,12 +277,20 @@ sub MySchedulerId {
 	$classVars->{cfg}{schedulerId};
 }
 
+sub TerminateUSR2 {
+	my $self = shift;
+
+	$self->LogSysTrace("Received Signal USR2");
+	return 1 unless ($self->MyId() == -1);
+	$self->UpdateMyStatus ({ rt_status => 'paused' });
+	exit;
+}
+
 sub Terminate {
 	my $self = shift;
 
 	$self->LogSysTrace("Received Signal USR1");
-	return 1 unless ($self->MyId() == -1);
-	$self->UpdateMyStatus ({ rt_status => 'paused' });
+	$self->UpdateMyStatus ({ rt_status => 'stopped' });
 	exit;
 }
 	
@@ -568,57 +579,60 @@ sub load_crontab {
 
 	my $schedcount = 0;
 	my @asap;
-	return unless ($count->{countschedules} > 0);
+	if ($count->{countschedules} > 0) {
 
-	$self->clean_timetable();
-	foreach my $sched (@$scheds) {
-		next unless ($sched->{sched_id});
-		$schedcount++;
-		my $time = "$sched->{sched_min} $sched->{sched_hour} $sched->{sched_mday} $sched->{sched_month} $sched->{sched_wday}";
-		my @args = ("", $sched->{object_id}, $sched->{tracefile}, $sched->{errorfile}, $sched->{sched_id});
-		print STDERR cafUtils->datetime1(), " $$ ADDING ENTRY $sched->{sched_id} $sched->{sched_mode} $sched->{object_id} \n";
-		if ($sched->{sched_mode} eq 'asap') {
-			$args[0] = "asap";
-			push @asap, \@args;
-			$query->clear({sched_id => $sched->{sched_id}});
-			$query->dwscheduler();
-			$qDbh->executefinish($query);
-			next;
-		}
-		if ($sched->{sched_mode} eq 'once') {
-			$args[0] = "execute";
-		}
-		elsif ($sched->{sched_id} eq "archiver") {
-			$args[0] = "archiver";
-		}
-		elsif ($sched->{sched_id} eq "monitor") {
-			$args[0] = "monitor";
-			$self->TraceFile($sched->{tracefile}) unless ($self->TraceFile());
-			$self->ErrorFile($sched->{errorfile}) unless ($self->ErrorFile());
-		}
-		else {
-			if ($sched->{object_id} > 0) {
+		$self->clean_timetable();
+		foreach my $sched (@$scheds) {
+			next unless ($sched->{sched_id});
+			$schedcount++;
+			my $time = "$sched->{sched_min} $sched->{sched_hour} $sched->{sched_mday} $sched->{sched_month} $sched->{sched_wday}";
+			my @args = ("", $sched->{object_id}, $sched->{tracefile}, $sched->{errorfile}, $sched->{sched_id});
+			print STDERR cafUtils->datetime1(), " $$ ADDING ENTRY $sched->{sched_id} $sched->{sched_mode} $sched->{object_id} \n";
+			if ($sched->{sched_mode} eq 'asap') {
+				$args[0] = "asap";
+				push @asap, \@args;
+				$query->clear({sched_id => $sched->{sched_id}});
+				$query->dwscheduler();
+				$qDbh->executefinish($query);
+				next;
+			}
+			if ($sched->{sched_mode} eq 'once') {
+				$args[0] = "execute";
+			}
+			elsif ($sched->{sched_id} eq "archiver") {
+				$args[0] = "archiver";
+			}
+			elsif ($sched->{sched_id} eq "monitor") {
+				$args[0] = "monitor";
 				$self->TraceFile($sched->{tracefile}) unless ($self->TraceFile());
 				$self->ErrorFile($sched->{errorfile}) unless ($self->ErrorFile());
 			}
-			$args[0] = "daemon";
+			else {
+				if ($sched->{object_id} > 0) {
+					$self->TraceFile($sched->{tracefile}) unless ($self->TraceFile());
+					$self->ErrorFile($sched->{errorfile}) unless ($self->ErrorFile());
+				}
+				$args[0] = "daemon";
+			}
+	
+			print STDERR cafUtils->datetime1(), " $$ ADD ENTRY ", join (" ", @args), "\n";
+			$self->add_entry($time, { arguments => \@args });
+		}
+	
+		unless ($schedcount) {
+			if ($self->MyFlowId() > 0) {
+				$self->UpdateMyStatus({ rt_status_cond => "online", rt_status => "paused" });
+				print STDERR cafUtils->datetime1(), " $$ Exiting No Entry in the Cron Table \n";
+				exit;
+			}
+			else { $self->add_entry ("0-59/5 * * * *", { arguments => [ "monitor",undef, undef, undef, "monitor" ] }); }
 		}
 
-		print STDERR cafUtils->datetime1(), " $$ ADD ENTRY ", join (" ", @args), "\n";
-		$self->add_entry($time, { arguments => \@args });
-	}
-
-	unless ($schedcount) {
-		if ($self->MyFlowId() > 0) {
-			$self->UpdateMyStatus({ rt_status_cond => "online", rt_status => "paused" });
-			print STDERR cafUtils->datetime1(), " $$ Exiting No Entry in the Cron Table \n";
-			exit;
-		}
-		else { $self->add_entry ("0-59/5 * * * *", { arguments => [ "monitor",undef, undef, undef, "monitor" ] }); }
-	}
+	} #if ($count->{countschedules} > 0) 
 
 	$self->QueueDisconnect() if ($disconnect);
 	foreach my $sched (@asap) {
+		next unless ($sched);
 		$self->ForkNewProcess($sched);
 	}
 	return $count->{countschedules};
