@@ -634,6 +634,10 @@ sub listtables {
 	return \@rows
 }
 
+sub GetTableKinds {
+   return undef;
+}
+
 sub protlisttables {
 	listtable(@_);
 }
@@ -654,14 +658,15 @@ sub describe {
 		unless ($c{$row->{COLUMN_NAME}}) {
 			$c{$row->{COLUMN_NAME}}=1;
 			$i++;
+#			print "$row->{COLUMN_NAME} ==> $row->{DATA_TYPE},$row->{SQL_DATA_TYPE},<BR>";
 			$rows[$i] = { 	externalname => $row->{COLUMN_NAME}, 
 				name         => $row->{COLUMN_NAME},
-				datatypeid   => $row->{SQL_DATA_TYPE},
+				datatypeid   => uc ($row->{DATA_TYPE} || $row->{SQL_DATA_TYPE}),
 				datalength   => $row->{COLUMN_SIZE},
 				datascale    => $row->{DECIMAL_DIGITS},
 				fieldorder   => $row->{ORDINAL_POSITION},
 				nullable     => $row->{IS_NULLABLE},
-				defaultvalue => $row->{OLUMN_DEF},
+				defaultvalue => $row->{COLUMN_DEF},
 				Remarks      => $row->{REMARKS},
 #{ name => $col, externalname => $col, datatypeid => 'VARCHAR', datalength => 100,  fieldorder => $i*10};
 			};
@@ -706,6 +711,7 @@ sub generateselect {
 
 	foreach my $col (@$fields) {
 		next if ($col->{localfield} eq "yes");
+		next unless ($col->{status} eq "online");
 		if ($qlen > 50) { $query .= "$sep\n\t\t"; $qlen = 16; $sep = ""; }
 		$chunk = "$sep" . $self->generatedatetochar($col) . " " . $self->gencolalias("\@c_$col->{name}");
 
@@ -747,6 +753,7 @@ sub generateupdate {
 
 	foreach my $col (@$fields) {
 		next if ($col->{localfield} eq "yes");
+		next unless ($col->{status} eq "online");
 		if ($qlen > 50) { $query .= "$sep\n\t\t"; $qlen = 16; $sep = ""; }
 		my $colname = $self->columnnameformat($col);
 		$chunk = "$sep$colname = " . $self->generatechartodate($col);
@@ -787,6 +794,7 @@ sub generatedelete {
 
 	foreach my $col (@$fields) {
 		next if ($col->{localfield} eq "yes");
+		next unless ($col->{status} eq "online");
 
 		if ($col->{keyposition}) {
 			my $colname = $self->columnnameformat($col);
@@ -820,6 +828,7 @@ sub generateinsert {
 
 	foreach my $col (@$fields) {
 		next if ($col->{localfield} eq "yes");
+		next unless ($col->{status} eq "online");
 		if ($qlen > 50) { $query .= "$sep\n\t\t"; $qlen = 16; $sep = ""; }
 		my $colname = $self->columnnameformat($col);
 		$chunk = "$sep$colname";
@@ -862,6 +871,8 @@ sub generatecreate {
 	my $chunk = "";
 
 	foreach my $col (@$fields) {
+		next if ($col->{localfield} eq "yes");
+		next unless ($col->{status} eq "online");
 		my $colname = $self->columnnameformat($col);
 		my $datatype = $datatypeconv{$col->{datatypeid}};
 		$query .= "$sep\n\t$colname $datatype";
