@@ -180,9 +180,9 @@ sub _setnavinfo {
         my $maxlistdisplay = $conf->maxlistdisplay();
 
 	$self->{_button} = {};
-	if ($rowscount > $maxlistdisplay) {
-		if ($lastrow < $rowscount) { $self->{_buttons}{$list . "bottom"} = 1; $self->{_buttons}{$list . "next"} = 1;}
-		if ($lastrow > $maxlistdisplay) { $self->{_buttons}{$list . "top"} = 1; $self->{_buttons}{$list . "prev"} = 1; }
+	if ($rowscount >= $maxlistdisplay) {
+		if ($lastrow <= $rowscount) { $self->{_buttons}{$list . "bottom"} = 1; $self->{_buttons}{$list . "next"} = 1;}
+		if ($lastrow >= $maxlistdisplay) { $self->{_buttons}{$list . "top"} = 1; $self->{_buttons}{$list . "prev"} = 1; }
 	}
 }
 
@@ -348,7 +348,7 @@ sub _updateattributes {
 #	while ($attrdefid = $cgi->param("attrdefid$i")) { $attrvalues->{$attrdefid} = $cgi->param("attrvalue$i"); $i++}
 	while ($attrdefid = $cgi->param("attrdefid$i")) {
 		$attrval = $cgi->param("attrvalue$i");
-		$attrvalues->{$attrdefid} = $attrval if ($attrval || (length($attrval) > 0));
+		$attrvalues->{$attrdefid} = $attrval; # if ($attrval || (length($attrval) > 0));
 		$i++
 	}
 	$dbh->updateattributes($self->_datavar("object_id"), $attrvalues);
@@ -608,6 +608,7 @@ sub describeContainer {
 	my $conf = shift;
 	my $connector = shift;
 	my $container = shift;
+	my $tableKind = shift;
 
 	#Get the field list
 	my $query;
@@ -616,7 +617,7 @@ sub describeContainer {
 
 	my $describe_list;
 	eval {
-		$describe_list = $drv->describe($container->{ externalname }, $container->{ externalschema }, $container->{ externaltype });
+		$describe_list = $drv->describe($container->{ externalname }, $container->{ externalschema }, $container->{ externaltype }, $tableKind);
 	};
 
 	if ($@) {
@@ -682,6 +683,7 @@ sub getSelectedContainer {
 	$container->{ status } = "online";
 	$container->{ remarks } = $cgi->param("_selectedremarks");
 	$container->{ comments } = $cgi->param("_selectedremarks");
+	$container->{ update } = $cgi->param("_selectedupdate");
 	$self->{_container} = $container;
 }
 
