@@ -159,7 +159,7 @@ sub prepare {
 		if ($cmd eq "select") {
 			my $tempfile = $self->getfile({ fname => $self->xmlinfo("_EXTERNALNAME"), mode => "r" });
 			$self->xmlinfo("_TEMPFILE", $tempfile);
-			$self->xmlinfo("_DATA", $self->readdata());
+			my $data = $self->xmlinfo("_DATA", $self->readdata());
 		}
 		else {
 			$self->xmlinfo("_DATA", [[]]);
@@ -284,15 +284,19 @@ sub xmlarraytohash {
 }
 
 sub setexternalname {
-        my $self = shift;
-        my $filename = shift;
-        $self->xmlinfo("_EXTERNALNAME", $filename);
+	my $self = shift;
+	my $filename = shift;
+	my $container = $self->{db}{container};
+	$container->{externalname} = $filename;
+
+	$self->xmlinfo("_EXTERNALNAME", $filename) if ($self->xmlinfo("_EXTERNALNAME"));
 }
 
 sub getexternalname {
-        my $self = shift;
-        my $filename = shift;
-        $self->xmlinfo("_EXTERNALNAME");
+	my $self = shift;
+	my $container = $self->{db}{container};
+
+	$self->xmlinfo("_EXTERNALNAME") || $container->{externalname};
 }
 
 
@@ -312,7 +316,8 @@ sub finalcommit {
 		my $rootname = $self->xmlattrib("rootname");
 		#$str =~ s/<$rootname>\s*<anon>/<$rootname>/;
 		#$str =~ s/[ \t]*<\/anon>\s*<\/$rootname>/<\/$rootname>/;
-		$str =~ s/\s*<[\/]*anon><\/$rootname>/<\/$rootname>/;
+		#$str =~ s/\s*<[\/]*anon><\/$rootname>/<\/$rootname>/;
+		$str =~ s/\s*<[\/]*anon>//g;
 
 		my $tempfile = $self->getfile({ fname => $self->xmlinfo("_EXTERNALNAME"), mode => "w" });
 		my $tempioh = IO::File->new($tempfile, "w");
