@@ -46,6 +46,16 @@ function finddiff {
 
 argcnt=$#
 if [ $argcnt -lt 2 ] || [ ! -d $1 ] || [ ! -d $2 ] ; then
+	echo "**ERROR $0 $*"
+	if [ ! -d $1 ] ; then
+		echo "**ERROR : directory $1 does not exist"
+		[ -d $2 ] && echo "_MAYBE /bin/cp -fR $2 $1"
+	fi
+
+	if [ ! -d $2 ] ; then
+		echo "**ERROR : directory $2 does not exist"
+		[ -d $1 ] && echo "_SUGGEST cp -fR $1 $2"
+	fi
 	echo "Usage $0 dir1 dir2 [pattern [exclude]]";
 else
 	dir1=$1
