@@ -9,9 +9,13 @@ require "/home/app/cafeterra/cgi/EN/translate.pm.old";
 my %e = %cafetrans::translation;
 %cafetrans::translation = undef;
 
+my %S;
+foreach my $k (keys %s) {
+	$S{uc $k} = $s{$k};
+}
 
 foreach $w (keys %e) {
-	if (! $s{$w}) {
+	if (! $S{uc $w}) {
 		print "EN ", sprintf("\"%-25s => \"%s\",\n", $w . "\"", $e{$w});
 		print "FR ", sprintf("\"%-25s => \"%s\",\n", $w . "\"",	$f{$w});
 	}
