@@ -80,7 +80,7 @@ sub ExtConnect {
 #	my $ptext = $dump->Dump;
 
 
-#	print "<BR>\n ==> $ptext <==\n";
+#	print STDERR "<BR>\n ==> $ptext <==\n";
 
 	die "No Driver ID supplied" unless ($db->{connector}{driverid});
 	die "No Protocol ID supplied" unless ($db->{connector}{protocolid});
@@ -425,6 +425,7 @@ sub getmyattributes {
 			$attrdef->{defaultlist} = \@defaults;
 		}
 		$attrdef->{attrvalue} = $attrdef->{attrdefault} unless ($attrdef->{attrvalue});
+		$attrdef->{attrvalue} = undef if ($attrdef->{attrvalue} eq '--attrnotset--');
 	}
 	$attrdefs;
 }
@@ -445,7 +446,9 @@ sub updateattributes {
 #		my $ret = $self->executefinish($query);
 #		if ($ret == 0) { $query->iattributes(); $self->executefinish($query); }
 
-		$query = $self->newquery({ object_id => $object_id, attrdefid => $attrdefid, attrvalue => $attrvalues->{$attrdefid} });
+		my $attrval = $attrvalues->{$attrdefid};
+		$attrval = '--attrnotset--' unless ($attrval || (length($attrval) > 0));
+		$query = $self->newquery({ object_id => $object_id, attrdefid => $attrdefid, attrvalue => $attrval, });
 		$query->iattributes();
 		$ret = $self->executefinish($query);
 		last unless ($ret > 0);
