@@ -169,11 +169,41 @@ function CafAtom () {
 }
 
 
+function ProcessContext () {
+	var theForm;
+	theForm = document.mainform;
+	var selectList = theForm._configlist;
+	var index = selectList.selectedIndex;
+	if (index > 0) {
+		theForm._nextaction.value = "search2";
+		theForm._contextid.value = selectList.options[index].value;
+		if (theForm._contextid.value == "cgi") { theForm._ctxttype.value = "design"; }
+		else { theForm._ctxttype.value = "prod"; }
+		theForm.submit();
+	}
+}
+
+function EditQueryOption (callerPage, relatedObject) {
+	var winName, newWin, winId, hForm, sessionId;
+	hForm = document.mainform;
+	var srcKind;
+	var scrLang = 'sql';
+	var selectList = hForm._GENERATEQUERY_;
+	var index = selectList.selectedIndex;
+	if (index > 0) {
+		srcKind = selectList.options[index].value;
+		srcKind = srcKind.toLowerCase();
+		EditScript2 (callerPage, relatedObject, srcKind, scrLang);
+	}
+}
+
 function EditScript3 (callerPage, relatedObject) {
 	var winName, newWin, winId, hForm, sessionId;
 	hForm = document.mainform;
-	var srcKind = hForm.scriptlist.value;
-	var scrLang = hForm.scriptlang.value
+	var selectList = hForm.scriptlist;
+	var index = selectList.selectedIndex;
+	var srcKind = selectList.options[index].value;
+	var scrLang = hForm.scriptlang.value;
 	EditScript2 (callerPage, relatedObject, srcKind, scrLang);
 }
 
@@ -187,7 +217,8 @@ function EditScript2 (callerPage, relatedObject, scrKind, scrLang) {
 	var returnFields = "script_id-script_name";
 	var evalstring = "hForm.script_id";
 	var e = eval (evalstring);
-	var scriptId = e.value;
+	var scriptId = '';
+	if (e != null) { scriptId = e.value; }
 	winSearchId = hForm._winsearchid.value;
 
 	if (winSearchId) { winSearchId++; }
@@ -203,7 +234,7 @@ function EditScript2 (callerPage, relatedObject, scrKind, scrLang) {
 	winName = "CafeterraSearch" + winSearchId;
 	// hForm.elements[0].style.cursor = "wait";
 	newWin=open(cmd,winName,"Scrollbars=1,resizable=1,screenX=1,screenY=1,width=800,height=400,status=1");
-	if (newWin.opener == null) newWin.opener = self;
+	if (newWin.opener == null) { newWin.opener = self; }
 	newWin.focus();
 	// hForm.elements[0].style.cursor = "auto";
 }
@@ -234,7 +265,7 @@ function EditScript (callerPage, relatedObject, iLine, scrKind, scrLang) {
 	winName = "CafeterraSearch" + winSearchId;
 	// hForm.elements[0].style.cursor = "wait";
 	newWin=open(cmd,winName,"Scrollbars=1,resizable=1,screenX=1,screenY=1,width=800,height=400,status=1");
-	if (newWin.opener == null) newWin.opener = self;
+	if (newWin.opener == null) { newWin.opener = self; }
 	newWin.focus();
 	// hForm.elements[0].style.cursor = "auto";
 }
@@ -343,6 +374,18 @@ function CreateImportParameters (iContainer) {
 		theForm.appendChild(e2);
 	}
 	e2.value = e1.value;
+
+	e1 = eval ("theForm.update_" + iContainer);
+	if (e1 != null) {
+		e2 = eval ("theForm._selectedupdate");
+		if (e2 == null) {
+			e2 = document.createElement("input");
+			e2.type = "hidden";
+			e2.name = "_selectedupdate";
+			theForm.appendChild(e2);
+		}
+		e2.value = e1.value;
+	}
 }
 
 function ValidateImportContainer(nextPage, nextAction, actionDetail, iContainer) {
@@ -357,7 +400,7 @@ function ValidateImportContainer(nextPage, nextAction, actionDetail, iContainer)
 	theForm.submit();
 }
 
-function ValidateImportFields(nextPage, nextAction, iContainer) {
+function ValidateImportFields(nextPage, nextAction, actionDetail, iContainer) {
 	var theForm = document.forms[0];
 	theForm._nextpage.value = nextPage;
 	theForm._nextaction.value = nextAction;
@@ -449,7 +492,7 @@ function OpenChooser (callerPage, calledPage, returnFields, searchCriteria) {
 	winName = "CafeterraSearch" + winSearchId;
 	// hForm.elements[0].style.cursor = "wait";
 	newWin=open(cmd,winName,"Scrollbars=1,resizable=1,screenX=1,screenY=1,width=900,height=600,status=1");
-	if (newWin.opener == null) newWin.opener = self;
+	if (newWin.opener == null) { newWin.opener = self; }
 	newWin.focus();
 	// hForm.elements[0].style.cursor = "auto";
 }
@@ -504,7 +547,7 @@ function SelectThis(v0, v1, v2, v3, v4) {
 	}
 	if (ee != null) { eval ("ee.focus()"); }
 
-//	window.close();
+	window.close();
 }
 /*
 */
